@@ -943,3 +943,6 @@ class MainWindow(BaseMainWindow):
     @staticmethod
     def get_project_info(file_path, image):
         return SegmentationTuple(file_path=file_path, image=image)
+
+    def set_data(self, data):
+        self.main_menu.set_data(data)
